==> neo4j-java-driver-4.4.1-sources.jar: org/neo4j/driver/internal/cluster/ClusterCompositionLookupResult.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.neo4j.driver.internal.cluster;

import java.util.Optional;
import java.util.Set;

import org.neo4j.driver.internal.BoltServerAddress;

public class ClusterCompositionLookupResult
{
    private final ClusterComposition composition;

    private final Set<BoltServerAddress> resolvedInitialRouters;

    public ClusterCompositionLookupResult( ClusterComposition composition )
    {
        this( composition, null );
    }

    public ClusterCompositionLookupResult( ClusterComposition composition, Set<BoltServerAddress> resolvedInitialRouters )
    {
        this.composition = composition;
        this.resolvedInitialRouters = resolvedInitialRouters;
    }

    public ClusterComposition getClusterComposition()
    {
        return composition;
    }

    public Optional<Set<BoltServerAddress>> getResolvedInitialRouters()
    {
        return Optional.ofNullable( resolvedInitialRouters );
    }
}

==> neo4j-java-driver-4.4.11-sources.jar: org/neo4j/driver/internal/cluster/ClusterCompositionLookupResult.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.neo4j.driver.internal.cluster;

import java.util.Optional;
import java.util.Set;
import org.neo4j.driver.internal.BoltServerAddress;

public class ClusterCompositionLookupResult {
    private final ClusterComposition composition;

    private final Set<BoltServerAddress> resolvedInitialRouters;

    public ClusterCompositionLookupResult(ClusterComposition composition) {
        this(composition, null);
    }

    public ClusterCompositionLookupResult(
            ClusterComposition composition, Set<BoltServerAddress> resolvedInitialRouters) {
        this.composition = composition;
        this.resolvedInitialRouters = resolvedInitialRouters;
    }

    public ClusterComposition getClusterComposition() {
        return composition;
    }

    public Optional<Set<BoltServerAddress>> getResolvedInitialRouters() {
        return Optional.ofNullable(resolvedInitialRouters);
    }
}
